@@ -1,10 +1,15 @@
+# coding=utf-8
 class StatcordException(Exception):
-    """Base exception for all statcord exceptions"""
     def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        super().__init__(*args)
 
 
 class RequestFailure(StatcordException):
-    """Raised when a request to the statcord api fails"""
     def __init__(self, status: int, response: str):
         super().__init__("{}: {}".format(status, response))
+
+
+class TooManyRequests(RequestFailure):
+    def __init__(self, status: int, response: str, wait: int):
+        self.wait = wait
+        super().__init__(status, response)
